/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.agent;

import com.fasterxml.jackson.annotation.JsonProperty;


public class ComponentRecoveryReport {
  private String name;
  private int numAttempts;
  private boolean limitReached;


  @JsonProperty("name")
  public String getName() {
    return name;
  }

  @JsonProperty("name")
  public void setName(String name) {
    this.name = name;
  }

  @JsonProperty("num_attempts")
  public int getNumAttempts() {
    return numAttempts;
  }

  @JsonProperty("num_attempts")
  public void setNumAttempts(int numAttempts) {
    this.numAttempts = numAttempts;
  }

  @JsonProperty("limit_reached")
  public boolean getLimitReached() {
    return limitReached;
  }

  @JsonProperty("limit_reached")
  public void setLimitReached(boolean limitReached) {
    this.limitReached = limitReached;
  }

  @Override
  public String toString() {
    return "ComponentRecoveryReport{" +
           "name='" + name + '\'' +
           ", numFailures='" + numAttempts + '\'' +
           ", limitReached='" + limitReached + '\'' +
           '}';
  }
}
